.. hello2 documentation master file, created by
   sphinx-quickstart on Fri Nov  4 21:36:31 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to hello2's documentation!
==================================

.. toctree::
   :maxdepth: 2
   :caption: Python API

   modules
   hello.fiftyone
   hello.mmdet
   hello.mmseg
   hello.onnx
   hello.transforms
   hello.utils
   hello.video
   hello.x3m



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
